@@ -29,8 +29,10 @@ class MachineLearningModel(object):
         #     logger.error(message)
         #     raise FileNotFoundError(message)
         package_dir = os.path.dirname(os.path.abspath(__file__))
+        thefile = os.path.join(package_dir,'TrainedModel_c++.ann')
         print(package_dir)
-        mypath = path("tqatest.ml.model", "TrainedModel_c++.ann")
+        # mypath = path("tqatest.ml.model", "TrainedModel_c++.ann")
+
         # self.load_model(str(mypath))
     
     def load_model(self, mypath : str):
